##  Save Your Results
When you’ve identified a selection of applications to evaluate, save these results so you can access the information later. To save, do the following:
  1. Choose Save as new in the three-dot menu.
  2. In the overlay, enter a name for the list of applications and set permissions.
Saving a List of Filtered Fact Sheets
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio550ea120b25e4ee8872de87d8a1548a8_LowRes.png)
  3. Choose Save. To re-open your search, go to the **Searches** tab in the left panel and choose your saved search.
